@@ -179,6 +179,11 @@ class HestiaPi(Sensor):
 
             elif state == HVAC.OFF:
                 self._modes[mode].off()
+                
+                if mode == HVAC.COOL:
+                    time.sleep(3)
+                    self._modes['_cool'].off()
+
                 if mode not in [HVAC.FAN, HVAC.BOOST]:
                     self.active_start_time = None
                     self.temperature_history = []
